#!/bin/bash


function make_arch_package() {
    version=$1

    cat > PKGBUILD << EOF
pkgname=thunar-encryption-plugin
pkgver=$version
pkgrel=1
pkgdesc='Thunar CryFS, EncFS or FSCrypt encrypted folder extension'
arch=('x86_64' 'aarch64')
url='https://fox-echo.info/thunar-encryption-plugin'
license=('CeCILL')
depends=('gtk3' 'thunar')
makedepends=('cmake' 'make' 'gcc')
source=(\$pkgname-\$pkgver.tar.gz)
md5sums=(SKIP)

build() {
    cd \$pkgname-\$pkgver
    mkdir -p build
    cd build
    cmake .. -DCMAKE_INSTALL_PREFIX=/usr -DCMAKE_INSTALL_DOCDIR=share/doc
    make
}

package() {
    cd \$pkgname-\$pkgver/build
    make install DESTDIR="\$pkgdir"
    mv "\$pkgdir"/usr/share/doc/\$pkgname-\$pkgver "\$pkgdir"/usr/share/doc/\$pkgname
    install -Dm644 "\$srcdir"/\$pkgname-\$pkgver/doc/License_CeCILL_V2.1-en.txt "\$pkgdir"/usr/share/licenses/\$pkgname/LICENSE
}

EOF
    makepkg -f
    rm -rf PKGBUILD src pkg thunar-encryption-plugin-debug-$version-1-*.pkg.tar.*
    mv thunar-encryption-plugin-$version-1-*.pkg.tar.* arch/
}


function make_slackware_package() {
    version=$1

    arch=$(uname -m); libdir="lib"; if echo $arch | grep -q "64"; then libdir="lib64"; else arch="i586"; fi
    tar -zxvf thunar-encryption-plugin-$version.tar.gz; cd thunar-encryption-plugin-$version
    mkdir -p build; cd build
    cmake .. -DCMAKE_INSTALL_PREFIX=/usr -DCMAKE_INSTALL_LIBDIR=$libdir
    make; make install DESTDIR=pack
    strip --strip-unneeded build/pack/usr/$libdir/thunarx-3/libthunar-encryption-plugin.so

    mkdir pack/install
    cat > pack/install/slack-desc << EOF
thunar-encryption-plugin: Thunar-Encryption-Plugin
thunar-encryption-plugin:
thunar-encryption-plugin: Thunar-Encryption-Plugin is a file-manager extension offering contextual menu:
thunar-encryption-plugin: - to create or open CryFS, EncFS or FSCrypt encrypted folders;
thunar-encryption-plugin: - to open a terminal in a folder.
thunar-encryption-plugin: It is written in C / Gtk3.
thunar-encryption-plugin:
thunar-encryption-plugin: https://fox-echo.info/thunar-encryption-plugin
thunar-encryption-plugin:
EOF
    #Slackware 'makepkg' faker
    cd pack; for lnk in $(find -type l); do
        name=$(basename $lnk); dir=$(dirname $lnk | cut -c2-); target=$(basename $(readlink $lnk))
        echo -e "( cd $dir ; rm -rf thunar-encryption-plugin )\n( cd $dir ; ln -sf $target thunar-encryption-plugin )" >> install/doinst.sh
        rm -f $lnk
    done; cd ..
    sudo chown -R root:root pack
    cd pack; find ./ | LC_COLLATE=C sort | sed '2,$s,^\./,,' | tar --no-recursion -T - -cvf - | xz --threads=0 -c > ../../../slackware/thunar-encryption-plugin-$version-$arch-orig.txz; cd ..
    sudo chown -R $USER pack

    cd ../..; rm -rf thunar-encryption-plugin-$version
}


function make_debian_package() {
    version=$1

    arch=$(uname -m); if [ "$arch" == "x86_64" ]; then arch="amd64"; else arch="arm64"; fi
    tar -zxvf thunar-encryption-plugin-$version.tar.gz; cd thunar-encryption-plugin-$version
    mkdir -p build; cd build
    cmake .. -DCMAKE_INSTALL_PREFIX=/usr
    make; make install DESTDIR=pack
    strip --strip-unneeded build/pack/usr/lib/thunarx-3/libthunar-encryption-plugin.so
    mkdir pack/DEBIAN
    cat > pack/DEBIAN/control << EOF
Package: thunar-encryption-plugin
Version: $version
Architecture: any
Depends: libgtk-3-0, thunar
Maintainer: Frank Endres <frankendres@tuxfamily.org>
Description: Thunar CryFS, EncFS or FSCrypt encrypted folder extension
Homepage: https://https://fox-echo.info/thunar-encryption-plugin/
EOF
    find pack -type d -exec chmod 755 {} \;
    sudo chown -R root:root pack
    sudo dpkg-deb --build pack; mv pack.deb ../../debian/thunar-encryption-plugin_"$version"_"$arch".deb
    sudo chown -R $USER pack
    cd ../..; rm -rf thunar-encryption-plugin-$version
}


changelog_version=$(cat doc/ChangeLog.md | grep "## " | head -n1 | sed 's/.* - v//')
cmake_version=$(cat CMakeLists.txt | grep "(PROJECT_VERSION \"" | cut -f2 -d\")
dir_version=$(basename $(pwd) | rev | cut -f1 -d- |rev)
if [ "$dir_version" != "$cmake_version" ] || [ "$dir_version" != "$changelog_version" ]; then
    echo "version error: dir=$dir_version CMakeLists.txt=$cmake_version, doc/ChangeLog.md=$changelog_version" >&2
    exit 1
fi
version=$dir_version

rm -rf releases www
cd ..; tar -czvf thunar-encryption-plugin-$version.tar.gz thunar-encryption-plugin-$version; cd thunar-encryption-plugin-$version
mkdir -p releases/{arch,slackware,debian}
mv ../thunar-encryption-plugin-$version.tar.gz releases/

cd releases
make_arch_package $version
make_slackware_package $version
make_debian_package $version
cd ..

gpg --detach-sign --sign $(ls releases/*.tar.gz)
gpg --detach-sign --sign $(ls releases/arch/*)
gpg --detach-sign --sign $(ls releases/debian/*)
gpg --detach-sign --sign $(ls releases/slackware/*)

if [ "$1" == "-u" ]; then
    ssh -4 -t root@fox-echo.info "mkdir -p /var/www/fox-echo.info/thunar-encryption-plugin"
    scp -4 -r releases/* root@fox-echo.info:/var/www/fox-echo.info/thunar-encryption-plugin/res/
    sitegen.sh
    scp -4 www/* root@fox-echo.info:/var/www/fox-echo.info/thunar-encryption-plugin/
fi
